@@ -3,11 +3,19 @@
 
 __author__ = 'https://github.com/akvilary'
 
+# core classes
 from .sql_query import SqlQuery
 from .sql_section import SqlSection
 from .sql_container import SqlContainer
 from .sql_cte import SqlCte
+
+# supplementary classes
 from .sql_enum import SqlEnum
+from .sql_col import SqlCol
 from .sql_cols import SqlCols
+from .sql_val import SqlVal
 from .sql_vals import SqlVals
 from .sql_section_header import SqlSectionHeader
+from .sql_filter import SqlFilter
+from .sql_filters import SqlFilters
+from .sql_placeholder import SqlPlaceholder
