@@ -8,9 +8,11 @@ __author__ = 'https://github.com/akvilary'
 from typing import Any
 
 from .sql_container import SqlContainer
+from .abstracts.string_convertible import StringConvertible
+from .abstracts.special_json_convertible import SpecialJsonConvertible
 
 
-class SqlEnum(list):
+class SqlEnum(list, StringConvertible, SpecialJsonConvertible):
     """
     SqlEnum class is invented for better experience to enumerate.
     """
@@ -20,13 +22,14 @@ class SqlEnum(list):
     ):
         super().__init__(statements)
 
-    def __repr__(self) -> str:
-        """Convert SqlContainer instance to str"""
+    def __str__(self) -> str:
         return str(self.multiline().wrap())
 
-    def __str__(self) -> str:
-        """Return SqlContainer as str"""
-        return repr(self)
+    def __json_str__(self) -> str:
+        return str(self.inline())
+
+    def __json_array__(self) -> list:
+        return list(str(x) for x in self)
 
     def inline(self) -> SqlContainer:
         """Get inline representation"""
